@@ -1,21 +1,24 @@
 /*
  * Copyright (C) 2002-2004 the xine project
+ * Copyright (C) 2004-2012 the libmms project
  * 
  * This file is part of LibMMS, an MMS protocol handling library.
- * 
- * xine is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the ree Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * 
- * xine is distributed in the hope that it will be useful,
+ * This file was originally a part of xine, a free video player.
+ *
+ * Libmms is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * Libmms is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA
  *
  * $Id: mms.c,v 1.31 2007/12/11 20:35:01 jwrdegoede Exp $
  *
@@ -54,7 +57,6 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <time.h>
-#include <iconv.h>
 
 /********** logging **********/
 #define lprintf(...) \
@@ -68,6 +70,7 @@
 #include "mms.h"
 #include "asfheader.h"
 #include "uri.h"
+#include "utf.h"
 #include "mms-common.h"
 
 /* 
@@ -447,24 +450,6 @@ static int send_command (mms_io_t *io, mms_t *this, int command,
   return 1;
 }
 
-static int string_utf16(iconv_t url_conv, char *dest, char *src, int dest_len)
-{
-  char *ip = src, *op = dest;
-  size_t ip_len = strlen(src);
-  size_t op_len = dest_len - 2; /* reserve 2 bytes for 0 termination */
-
-  if (iconv(url_conv, &ip, &ip_len, &op, &op_len) == (size_t)-1) {
-    lprintf("Error converting uri to unicode: %s\n", strerror(get_errno()));
-    return 0;
-  }
-  
-  /* 0 terminate the string */
-  *op++ = 0;
-  *op++ = 0;
-
-  return op - dest;
-}
-
 /*
  * return packet type
  */
@@ -727,7 +712,6 @@ int static mms_choose_best_streams(mms_io_t *io, mms_t *this) {
  */
 /* FIXME: got somewhat broken during xine_stream_t->(void*) conversion */
 mms_t *mms_connect (mms_io_t *io, void *data, const char *url, int bandwidth) {
-  iconv_t url_conv = (iconv_t)-1;
   mms_t  *this;
   int     res;
   uint32_t openid;
@@ -778,12 +762,6 @@ mms_t *mms_connect (mms_io_t *io, void *data, const char *url, int bandwidth) {
   if (mms_tcp_connect(io, this)) {
     goto fail;
   }
-  
-  url_conv = iconv_open("UTF-16LE", "UTF-8");
-  if (url_conv == (iconv_t)-1) {
-    lprintf("could not get iconv handle to convert url to unicode\n");
-    goto fail;
-  }
 
   /*
    * let the negotiations begin...
@@ -796,8 +774,9 @@ mms_t *mms_connect (mms_io_t *io, void *data, const char *url, int bandwidth) {
   mms_gen_guid(this->guid);
   sprintf(this->str, "NSPlayer/7.0.0.1956; {%s}; Host: %s", this->guid,
           this->connect_host);
-  res = string_utf16(url_conv, this->scmd_body + command_buffer.pos, this->str,
-                     CMD_BODY_LEN - command_buffer.pos);
+  res = mms_utf8_to_utf16le(this->scmd_body + command_buffer.pos,
+                            CMD_BODY_LEN - command_buffer.pos,
+                            this->str);
   if(!res)
     goto fail;
 
@@ -825,9 +804,9 @@ mms_t *mms_connect (mms_io_t *io, void *data, const char *url, int bandwidth) {
   mms_buffer_put_32 (&command_buffer, 0x00000000);
   mms_buffer_put_32 (&command_buffer, 0x00989680);
   mms_buffer_put_32 (&command_buffer, 0x00000002);
-  res = string_utf16(url_conv, this->scmd_body + command_buffer.pos,
-                     "\\\\192.168.0.129\\TCP\\1037",
-                     CMD_BODY_LEN - command_buffer.pos);
+  res = mms_utf8_to_utf16le(this->scmd_body + command_buffer.pos,
+                            CMD_BODY_LEN - command_buffer.pos,
+                            "\\\\192.168.0.129\\TCP\\1037");
   if(!res)
     goto fail;
 
@@ -864,8 +843,9 @@ mms_t *mms_connect (mms_io_t *io, void *data, const char *url, int bandwidth) {
     mms_buffer_put_32 (&command_buffer, 0x00000000); /* ?? */
     mms_buffer_put_32 (&command_buffer, 0x00000000); /* ?? */
 
-    res = string_utf16(url_conv, this->scmd_body + command_buffer.pos,
-                       this->uri, CMD_BODY_LEN - command_buffer.pos);
+    res = mms_utf8_to_utf16le(this->scmd_body + command_buffer.pos,
+                              CMD_BODY_LEN - command_buffer.pos,
+                              this->uri);
     if(!res)
       goto fail;
 
@@ -974,7 +954,6 @@ mms_t *mms_connect (mms_io_t *io, void *data, const char *url, int bandwidth) {
     }
   }
 
-  iconv_close(url_conv);
   lprintf("connect: passed\n");
  
   return this;
@@ -982,9 +961,6 @@ mms_t *mms_connect (mms_io_t *io, void *data, const char *url, int bandwidth) {
 fail:
   mms_close(this);
 
-  if (url_conv != (iconv_t)-1)
-    iconv_close(url_conv);
-
   return NULL;
 }
 
