@@ -1,21 +1,24 @@
 /*
  * Copyright (C) 2002-2003 the xine project
+ * Copyright (C) 2004-2012 the libmms project
+ * 
+ * This file is part of LibMMS, an MMS protocol handling library.
+ * This file was originally a part of xine, a free video player.
  *
- * This file is part of xine, a free video player.
+ * Libmms is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * xine is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * xine is distributed in the hope that it will be useful,
+ * Libmms is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA
  *
  * $Id: mmsh.c,v 1.16 2007/12/11 20:50:43 jwrdegoede Exp $
  *
@@ -307,7 +310,10 @@ static int get_answer (mms_io_t *io, mmsh_t *this) {
         len = 0;
       }
     } else {
-      len ++;
+      if (++len >= sizeof(this->buf)) {
+        lprintf("answer too large\n");
+        return 0;
+      }
     }
   }
   if (this->stream_type == MMSH_UNKNOWN) {
@@ -334,6 +340,7 @@ static int get_chunk_header (mms_io_t *io, mmsh_t *this) {
   }
   this->chunk_type       = LE_16 (&chunk_header[0]);
   this->chunk_length     = LE_16 (&chunk_header[2]);
+  this->chunk_seq_number = -1;
 
   switch (this->chunk_type) {
     case CHUNK_TYPE_DATA:
@@ -425,6 +432,7 @@ static int get_header (mms_io_t *io, mmsh_t *this) {
                      this->chunk_length);
             return MMSH_ERROR;
           }
+          interp_asf_header(this);
         }
       } else {
         break;
@@ -504,7 +512,6 @@ static int mmsh_connect_int (mms_io_t *io, mmsh_t *this, off_t seek, uint32_t ti
   if (get_header(io, this) == MMSH_ERROR)
     goto fail;
 
-  interp_asf_header(this);
   if (!this->asf_packet_len || !this->num_stream_ids)
     goto fail;
   
@@ -564,7 +571,6 @@ static int mmsh_connect_int (mms_io_t *io, mmsh_t *this, off_t seek, uint32_t ti
   if (get_header(io, this) != MMSH_SUCCESS)
     goto fail;
 
-  interp_asf_header(this);
   if (!this->asf_packet_len || !this->num_stream_ids)
     goto fail;
 
@@ -603,6 +609,7 @@ mmsh_t *mmsh_connect (mms_io_t *io, void *data, const char *url, int bandwidth)
   this->s               = -1;
   this->bandwidth       = bandwidth;
   this->http_request_number = 1;
+  this->chunk_seq_number = -1;
 
   if (this->proxy_url) {
     proxy_uri = gnet_uri_new(this->proxy_url);
@@ -691,10 +698,13 @@ static int get_media_packet (mms_io_t *io, mmsh_t *this) {
          *     0: stop
          *     1: a new stream follows
          */
-        if (this->chunk_seq_number == 0)
+        if (this->chunk_seq_number == 0) {
+          this->chunk_seq_number = -1;
           return EOS;
+        }
 
         this->http_request_number = 1;
+        this->chunk_seq_number = -1;
         if (!mmsh_connect_int (io, this, 0, 0))
           return MMSH_ERROR;
 
@@ -916,7 +926,7 @@ off_t mmsh_seek (mms_io_t *io, mmsh_t *this, off_t offset, int origin) {
     }
     
     lprintf("seek to %d, packet: %d\n", (int)dest, (int)dest_packet_seq);
-    if (!mmsh_connect_int(io, this, (dest_packet_seq+1) * this->asf_packet_len, 0)) {
+    if (!mmsh_connect_int(io, this, this->asf_header_len + dest_packet_seq * this->asf_packet_len, 0)) {
       /* Oops no more connection let our caller know things are fscked up */
       return this->current_pos = -1;
     }
