@@ -17,12 +17,24 @@
  * Boston, MA  02111-1307, USA.
  */
 
-/* FIXME: #include "gnet-private.h" */
-#include <glib.h>
 #include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
 
+#ifndef FALSE
+#define FALSE 0
+#define TRUE 1
+#endif
+
+#define g_strdup strdup
+#define g_strndup strndup
+#define g_malloc malloc
+#define g_free free
+#define g_new0(TYPE,num) calloc(num, sizeof(TYPE))
+
+#define g_return_val_if_fail(pred,val) if (!(pred)) return (val)
+#define g_return_if_fail(pred) if (!(pred)) return
+
 #include "uri.h"
 #include <string.h>
 
@@ -428,7 +440,11 @@ gnet_uri_equal (gconstpointer p1, gconstpointer p2)
   return FALSE;
 }
 
-
+/**
+ * remove gnet_uri_hash, as it uses non-trivial glib functions, but is
+ * not used by libmms
+ **/
+#if 0
 /**
  *  gnet_uri_hash
  *  @p: a #GURI
@@ -457,7 +473,7 @@ gnet_uri_hash (gconstpointer p)
   
   return h;
 }
-
+#endif /* #if 0, removing gnet_uri_hash definition */
 
 /**
  *  gnet_uri_escape
@@ -617,7 +633,11 @@ field_unescape (char* s)
 }
 
 
-
+/**
+ * remove gnet_uri_get_string, as it uses non-trivial glib functions, but is
+ * not used by libmms
+ **/
+#if 0
 /**
  *  gnet_uri_get_string
  *  @uri: a #GURI
@@ -688,7 +708,7 @@ gnet_uri_get_string (const GURI* uri)
   g_string_free (buffer, FALSE); 
   return rv;
 }
-
+#endif /* #if 0, removing gnet_uri_get_string definition */
 
 /**
  *  gnet_uri_set_scheme
